Background
==========

Users of the ``otupy`` are expected to be familiar with the following relevant documents: 

* `OpenC2 Language Specification <https://docs.oasis-open.org/openc2/oc2ls/v1.0/cs02/oc2ls-v1.0-cs02.pdf>`__
* `OpenC2 Architecture Specification <https://docs.oasis-open.org/openc2/oc2ls/v1.0/cs02/oc2ls-v1.0-cs02.pdf>`__
* `OpenC2 Specification for Transfer over HTTPS <https://docs.oasis-open.org/openc2/open-impl-https/v1.1/cs01/open-impl-https-v1.1-cs01.pdf>`__
* `OpenC2 Profile for Stateless Packet Filtering <https://docs.oasis-open.org/openc2/oc2slpf/v1.0/cs01/oc2slpf-v1.0-cs01.pdf>`__

Additional documents that are of interest for who wants to extend the library with more profiles and transfer protocols: 

* `OpenC2 Specification for Transfer over MQTT <https://docs.oasis-open.org/openc2/transf-mqtt/v1.0/cs01/transf-mqtt-v1.0-cs01.pdf>`__
* `OpenC2 Actuator Profile Development Process <https://docs.oasis-open.org/openc2/cn-appdev/v1.0/cn01/cn-appdev-v1.0-cn01.pdf>`__

